@@ -1,4 +1,4 @@
-/* $Id: basic.h,v 1.32 2005/04/10 00:22:16 stpohle Exp $ */
+/* $Id: basic.h,v 1.36 2006/08/15 14:12:19 patty21 Exp $ */
 /* basic types which we need everywhere */
 
 #ifndef _BC_BASIC_H_
@@ -74,13 +74,13 @@
 
 #define DEFAULT_UDPPORT 11000
 #define DEFAULT_GAMECACHEPORT "11111"
-#define DEFAULT_GAMECACHE "x.yz.to:11111"
+#define DEFAULT_GAMECACHE "ogc.yz.to:11111"
 #define GAMESRV_TIMEOUT 2000    /* Timeout of the GameSrv_GetEntry */
 
 #define UDP_TIMEOUT 15000
 #define BUF_SIZE 1024
 
-#define AUTOSTART 20            /* dedicated server autostart */
+#define AUTOSTART 20            /* server autostart */
 
 #define MW_IS_GFX_SELECT(__gfx_nr,__result) for (__result = (MAX_PLAYERS-1); (__result >= 0) && (players[__result].gfx_nr != __gfx_nr); __result--);
 
@@ -164,7 +164,8 @@ enum _direction {               // to handle directions better
 enum _mapselection {
         MAPS_select = 0,
         MAPS_randmap,
-        MAPS_randgen
+        MAPS_randgen,
+        MAPS_morerand
 };
 
 enum _mstatus {
@@ -191,7 +192,7 @@ enum _help_page {
 struct {
         Sint16 x;
         Sint16 y;
-} typedef _point;
+} __attribute__((packed)) typedef _point;
 
 
 struct {
