@@ -1,4 +1,4 @@
-/* $Id: gfx.h,v 1.8 2004/09/26 02:28:05 stpohle Exp $ */
+/* $Id: gfx.h,v 1.10 2005/04/09 18:22:40 stpohle Exp $ */
 #ifndef _GFX_H_
 
 #define _GFX_H_
@@ -60,6 +60,8 @@ struct __gfx {
 	_gfxani bomb;		// bomb animation
 	_gfxani ill;		// sick animation above the player
 	_gfxani dead;		// load the dead player animation
+	SDL_Surface *ghost;	// gfx of the ghost player.
+	SDL_Surface *ghost_small;	// small ghost player
 	_gfxani respawn;	// respawn image
 	
 	_gfxani menuselect; // The Menu Select GFX (the bomb ?)
@@ -82,6 +84,7 @@ extern void gfx_unlocksurface (SDL_Surface *surface);
 extern void redraw_logo_shaded (int x, int y, int w, int h, int c);
 extern void gfx_load_players (int sx, int sy);
 extern void gfx_free_players ();
+extern int gfx_get_nr_of_playergfx ();
 
 // gfxpixelimage.c
 extern void getRGBpixel (SDL_Surface *surface, int x, int y, int *R, int *G, int *B);
