@@ -1,4 +1,4 @@
-/* $Id: network.h,v 1.23 2004/12/26 04:19:21 stpohle Exp $
+/* $Id: network.h,v 1.24 2006/08/13 21:26:50 stpohle Exp $
  * network.h file... for everything what have to do with the network stuff 
  */
 
@@ -9,7 +9,7 @@
 #define _NETWORK_H_
 
 #define MAX_UDPDATA 1024
-#define PKG_RESENDCACHE_SIZE (64*1024)
+#define PKG_RESENDCACHE_SIZE 64
 #define PKG_IN_INDEX_NUM 512
 #define RESENDCACHE_TIMEOUT 400
 #define RESENDCACHE_TIMEOUT_MENU 3000
@@ -61,7 +61,7 @@ struct {  // this holds the network data
 	char host[LEN_SERVERNAME];
 	char port[LEN_PORT];
 	struct _sockaddr sAddr;
-	signed char pl_nr; // pl_nr so we know it in the pkgcahce.
+	signed char pl_nr; // pl_nr so we know it in the pkgcache.
 } typedef _net_addr;
 
 
