@@ -1,4 +1,4 @@
-/* $Id: packets.h,v 1.34 2006/08/15 15:00:31 stpohle Exp $
+/* $Id: packets.h,v 1.37 2007/02/22 21:32:58 stpohle Exp $
  * network packets.. */
 
 #ifndef _PACKETS_H_
@@ -212,15 +212,15 @@ struct pkg_bombdata {
 	struct pkgheader h;
     unsigned char p_nr;
     unsigned char b_nr;
-    Uint16 x;
-    Uint16 y;
+    Sint16 x;
+    Sint16 y;
     unsigned char state;
     unsigned char r;
     Sint32 ex_nr;
     Sint32 to;
-    Uint16 destx;
-    Uint16 desty;
-	Sint16 speed;
+    Sint16 destx;
+    Sint16 desty;
+	Sint16 fdata;
 } __attribute__((packed));
 
 struct pkg_quit {
