@@ -1,4 +1,4 @@
-/* $Id: player.h,v 1.9 2004/10/18 20:20:22 stpohle Exp $
+/* $Id: player.h,v 1.11 2007/01/12 22:42:31 stpohle Exp $
  * playerinclude file
  */
 
@@ -67,6 +67,7 @@ struct {
 	int numuse;					// num of uses left
 	int use;					/* currently used set by special_use 
 								   and deleted in special_loop */
+	int clear;					// do we need to clear this special
 } typedef _special;
 
 
@@ -132,7 +133,7 @@ extern void player_move (int pl_nr);
 extern float stepmove_player (int pl_nr);
 extern void player_drop_bomb (int pl_nr);
 extern void get_player_on (float x, float y, int pl_nr[]);
-extern void player_died (_player * player, signed char dead_by);
+extern void player_died (_player * player, signed char dead_by, int network);
 extern void draw_players ();
 extern void player_animation (_player * player);
 extern int check_field (short int x, short int y);
