@@ -1,4 +1,4 @@
-/* $Id: configuration.c,v 1.80 2006/08/15 00:57:46 stpohle Exp $
+/* $Id: configuration.c,v 1.82 2007/12/07 22:06:57 stpohle Exp $
  * configuration */
 
 #include <SDL.h>
@@ -368,6 +368,18 @@ config_read ()
         if (!strcmp (keyword, "start_speed")) {
             sscanf (value, "%f", &bman.start_speed);
         }
+        if (!strcmp (keyword, "special_trigger")) {
+            sscanf (value, "%d", &map.sp_trigger);
+        }
+        if (!strcmp (keyword, "special_row")) {
+            sscanf (value, "%d", &map.sp_row);
+        }
+        if (!strcmp (keyword, "special_push")) {
+            sscanf (value, "%d", &map.sp_push);
+        }
+        if (!strcmp (keyword, "special_kick")) {
+            sscanf (value, "%d", &map.sp_kick);
+        }
         if (!strcmp (keyword, "bomb_ticking")) {
             sscanf (value, "%f", &bman.bomb_tickingtime);
         }
@@ -484,6 +496,11 @@ config_write ()
     fprintf (config, "start_bombs=%d\n", bman.start_bombs);
     fprintf (config, "start_range=%d\n", bman.start_range);
     fprintf (config, "start_speed=%f\n", bman.start_speed);
+	fprintf (config, "special_trigger=%d\n", map.sp_trigger);
+	fprintf (config, "special_row=%d\n", map.sp_row);
+	fprintf (config, "special_push=%d\n", map.sp_push);
+	fprintf (config, "special_kick=%d\n", map.sp_kick);
+
     fprintf (config, "bomb_ticking=%f\n", bman.bomb_tickingtime);
 	fprintf (config, "dropitemsondeath=%d\n",bman.dropitemsondeath);
 
@@ -532,8 +549,10 @@ config_video ()
         {"800x600", NULL},
         {"1024x768", NULL},
         {"1280x1024", NULL},
-        {"1600x1200", NULL},
-	{"1280x800", NULL}
+		{"1600x1200", NULL},
+        {"1920x1080", NULL},
+        {"1920x1200", NULL},        
+		{"1280x800", NULL}
     };
     _charlist screenbpp[] = {
         {"16", NULL},
