@@ -40,7 +40,7 @@ void d_playerdetail (char *head) {
 	d_printf ("---------------> %s\n", head);
 	d_printf ("Nr Name              GFX Sta Pkt Win Team net_flag [Addr]\n");
 	for (i = 0; i < MAX_PLAYERS; i++)
-		d_printf ("%2d %16s %3d %3d %3d %3d %4d   %3d     [%s:%s]\n",i, players[i].name, players[i].gfx_nr, players[i].state, players[i].points, players[i].wins, players[i].team_nr, players[i].net.flags, players[i].net.addr.host, players[i].net.addr.port);
+		d_printf ("%2d %16s %3d %3d %3d %3d %4d   %3d     %p[%s:%s]\n",i, players[i].name, players[i].gfx_nr, players[i].state, players[i].points, players[i].wins, players[i].team_nr, players[i].net.flags, players[i].net.addr.host, &players[i].net.addr, players[i].net.addr.port);
 };
 
 
