@@ -1,4 +1,4 @@
-/* $Id: field.c,v 1.59 2006/08/15 16:05:09 stpohle Exp $ */
+/* $Id: field.c,v 1.60 2006/12/15 18:41:45 stpohle Exp $ */
 /* field.c - procedures which are needed to control the field */
 
 #include "bomberclone.h"
@@ -185,16 +185,21 @@ draw_stone (int x, int y)
             stone_drawfire (x, y, -1);
 			break;
         }
-/*
+
 	if (debug) {
 		char txt[64];
+		/* ex numbers..
 		sprintf (txt, "%d,%d%d", map.field[x][y].ex[0].count, map.field[x][y].ex[0].bomb_p, map.field[x][y].ex[0].bomb_b); font_gfxdraw (dest.x, dest.y, txt, 0, COLOR_white, (y*256) + 10);
 		sprintf (txt, "%d,%d%d", map.field[x][y].ex[1].count, map.field[x][y].ex[1].bomb_p, map.field[x][y].ex[1].bomb_b); font_gfxdraw (dest.x, dest.y+10, txt, 0, COLOR_white, (y*256) + 10);
 		sprintf (txt, "%d,%d%d", map.field[x][y].ex[2].count, map.field[x][y].ex[2].bomb_p, map.field[x][y].ex[2].bomb_b); font_gfxdraw (dest.x, dest.y+20, txt, 0, COLOR_white, (y*256) + 10);
 		sprintf (txt, "%d,%d%d", map.field[x][y].ex[3].count, map.field[x][y].ex[3].bomb_p, map.field[x][y].ex[3].bomb_b); font_gfxdraw (dest.x, dest.y+30, txt, 0, COLOR_white, (y*256) + 10);
-
+		*/
+	
+		/* number of bombs.. */		
+		sprintf (txt, "%d", map.bfield[x][y]); 
+		font_gfxdraw (dest.x, dest.y+30, txt, 0, COLOR_white, (y*256) + 10);
 	}
-*/
+
     return;
 };
 
