@@ -1,4 +1,4 @@
-/* $Id: game.c,v 1.115 2006/08/15 02:15:39 stpohle Exp $ 
+/* $Id: game.c,v 1.118 2007/01/12 22:42:31 stpohle Exp $ 
   game.c - procedures for the game. */
 
 #include <string.h>
@@ -520,6 +520,8 @@ game_start ()
         players[p].speed = bman.start_speed;
         players[p].collect_shoes = 0;
         players[p].special.type = SP_nothing;
+		players[p].special.use = 0;
+		players[p].special.clear = 0;
         players[p].m = 0;
         players[p].old.x = 0;
         players[p].old.y = 0;
@@ -539,7 +541,7 @@ game_start ()
         for (i = 0; i < MAX_BOMBS; i++) {
             players[p].bombs[i].state = BS_off;
             players[p].bombs[i].ex_nr = -1;
-            players[p].bombs[i].speed = 0;
+            players[p].bombs[i].fdata = 0;
             players[p].bombs[i].dest.x = 0;
             players[p].bombs[i].dest.y = 0;
             players[p].bombs[i].mode = BM_normal;
@@ -993,3 +995,14 @@ game_menu_loop (SDL_Event * event, int eventstate)
         }
     }
 };
+
+
+/* reset all old gamedata, this is only needed on join, host or 
+ * new singleplayer games. */
+void game_resetdata () {
+	int i;
+	
+	for (i = 0; i < MAX_PLAYERS; i++)
+		memset (&players[i], 0, sizeof (_player));
+	bman.p2_nr = bman.p_nr = -1;
+};
