@@ -1,4 +1,4 @@
-/* $Id: gfx.c,v 1.40 2005/04/09 18:22:40 stpohle Exp $ */
+/* $Id: gfx.c,v 1.41 2005/07/06 13:11:55 stpohle Exp $ */
 /* gfx.c */
 
 #include "bomberclone.h"
@@ -26,7 +26,7 @@ int gfx_get_nr_of_playergfx () {
 		sprintf (filename, "%s/player/player%d.png", bman.datapath, i);
 		f = fopen (filename, "r");
 	} while (f);
-	
+
 	return i;
 }
 
@@ -66,23 +66,16 @@ gfx_load_players (int sx, int sy)
             gfx.players[i].ani.w = (tmpimage->w / 4) * sfkt;
             gfx.players[i].ani.frames = tmpimage->h / GFX_PLAYERIMGSIZE_Y;
 			
-			if (!bman.dedicated) {
-	            tmpimage1 =
-    	            scale_image (tmpimage, gfx.players[i].ani.w * 4,
-        	                     gfx.players[i].ani.frames * gfx.players[i].ani.h);
-            	getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-	            SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-	            gfx.players[i].ani.image = SDL_DisplayFormat (tmpimage1);
-    	        SDL_FreeSurface (tmpimage1);
-
-        	    /* calculate the numbers of images for the animation */
-    	        gfx.players[i].offset.x = (sx - gfx.players[i].ani.w) / 2;
-	            gfx.players[i].offset.y = -sy;
-			}
-			else 
-				gfx.players[i].ani.image = NULL;
-
-           	SDL_FreeSurface (tmpimage);
+            tmpimage1 = scale_image (tmpimage, gfx.players[i].ani.w * 4, gfx.players[i].ani.frames * gfx.players[i].ani.h);
+            getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+            SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+	    gfx.players[i].ani.image = SDL_DisplayFormat (tmpimage1);
+            SDL_FreeSurface (tmpimage1);
+	    
+	    /* calculate the numbers of images for the animation */
+	    gfx.players[i].offset.x = (sx - gfx.players[i].ani.w) / 2;
+	    gfx.players[i].offset.y = -sy;
+	    SDL_FreeSurface (tmpimage);
         }
     }
 
@@ -96,48 +89,38 @@ gfx_load_players (int sx, int sy)
     }
 
     gfx.dead.frames = tmpimage->h / (2* GFX_IMGSIZE);
-	if (!bman.dedicated) {
-		tmpimage1 = 
-	        scale_image (tmpimage, ((2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE)),
-    	                 gfx.dead.frames * (2 * sy));
-	    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-    	SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-	    gfx.dead.image = SDL_DisplayFormat (tmpimage1);
-    	SDL_FreeSurface (tmpimage1);
-	    SDL_FreeSurface (tmpimage);
-
-    	/* load the illnessthing */
-	    sprintf (filename, "%s/player/playersick.png", bman.datapath);
-	    tmpimage = IMG_Load (filename);
-    	if (tmpimage == NULL) {
-        	printf ("Can't load image: %s\n", SDL_GetError ());
-    	   	exit (1);
-	    }
-    	gfx.ill.frames = tmpimage->h / (2 * GFX_IMGSIZE);
-	    tmpimage1 =
-    	    scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
-        	             gfx.ill.frames * (2 * sy));
-	    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-    	SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-	    gfx.ill.image = SDL_DisplayFormat (tmpimage1);
-    	SDL_FreeSurface (tmpimage);
-	    SDL_FreeSurface (tmpimage1);
-	
-	    /* load the respawn gfx */
-    	sprintf (filename, "%s/player/respawn.png", bman.datapath);
-	    tmpimage = IMG_Load (filename);
-    	if (tmpimage == NULL) {
-        	printf ("Can't load image: %s\n", SDL_GetError ());
-	        exit (1);
-    	}
-	    gfx.respawn.frames = tmpimage->h / (2 * GFX_IMGSIZE);
-    	gfx.respawn.image  =
-        	scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
-            	         gfx.respawn.frames * (2 * sy)); 
-	    SDL_FreeSurface (tmpimage);
-	}
-	else
-		SDL_FreeSurface (tmpimage);
+    tmpimage1 = scale_image (tmpimage, ((2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE)), gfx.dead.frames * (2 * sy));
+    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+    SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+    gfx.dead.image = SDL_DisplayFormat (tmpimage1);
+    SDL_FreeSurface (tmpimage1);
+    SDL_FreeSurface (tmpimage);
+    
+    /* load the illnessthing */
+    sprintf (filename, "%s/player/playersick.png", bman.datapath);
+    tmpimage = IMG_Load (filename);
+    if (tmpimage == NULL) {
+	printf ("Can't load image: %s\n", SDL_GetError ());
+	exit (1);
+    }
+    gfx.ill.frames = tmpimage->h / (2 * GFX_IMGSIZE);
+    tmpimage1 = scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE), gfx.ill.frames * (2 * sy));
+    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+    SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+    gfx.ill.image = SDL_DisplayFormat (tmpimage1);
+    SDL_FreeSurface (tmpimage);
+    SDL_FreeSurface (tmpimage1);
+   
+    /* load the respawn gfx */
+    sprintf (filename, "%s/player/respawn.png", bman.datapath);
+    tmpimage = IMG_Load (filename);
+    if (tmpimage == NULL) {
+	printf ("Can't load image: %s\n", SDL_GetError ());
+	exit (1);
+    }
+    gfx.respawn.frames = tmpimage->h / (2 * GFX_IMGSIZE);
+    gfx.respawn.image  = scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE), gfx.respawn.frames * (2 * sy)); 
+    SDL_FreeSurface (tmpimage);
 };
 
 
@@ -146,8 +129,8 @@ void
 gfx_free_players ()
 {
     int i;
-
-	d_printf ("gfx_free_players\n");
+    
+    d_printf ("gfx_free_players\n");
 	
     for (i = 0; i < gfx.player_gfx_count; i++) {
         if (gfx.players[i].ani.image != NULL)
@@ -170,22 +153,15 @@ gfx_init ()
 {
 	int i;
 
-    if (gfx.fullscreen && !bman.dedicated)
-        gfx.screen =
-            SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp,
-                              SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL | SDL_FULLSCREEN);
+    if (gfx.fullscreen)
+        gfx.screen = SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp, SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL | SDL_FULLSCREEN);
 
-    else if (!bman.dedicated)
-        gfx.screen =
-            SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp,
-                              SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL);
-    if (!bman.dedicated && gfx.screen == NULL) {
+    else
+        gfx.screen = SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp, SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL);
+    if (gfx.screen == NULL) {
         d_printf ("Unable to set video mode: %s\n", SDL_GetError ());
         return;
     }
-	else if (bman.dedicated) {
-		gfx.screen = NULL;
-	}
     SDL_ShowCursor (SDL_DISABLE);
 	
 	/* delete small gfx und the menu player gfx */
@@ -532,14 +508,13 @@ draw_logo ()
 {
 	SDL_Rect dest;
 	
-	if (bman.dedicated) return;
 	
 	dest.x = dest.y = 0;
 	dest.w = gfx.res.x;
 	dest.h = gfx.res.y;
 	
-    SDL_BlitSurface (gfx.logo, NULL, gfx.screen, NULL);
-    gfx_blitupdaterectadd (&dest);
+	SDL_BlitSurface (gfx.logo, NULL, gfx.screen, NULL);
+	gfx_blitupdaterectadd (&dest);
 };
 
 
