@@ -1,4 +1,4 @@
-/* $Id: keyb.c,v 1.5 2004/09/13 22:15:57 stpohle Exp $
+/* $Id: keyb.c,v 1.6 2005/08/07 17:46:21 stpohle Exp $
  * keyb.c
  */
 
@@ -202,7 +202,7 @@ void keyb_config_readkey (int key) {
                 reorder = 0;
         }
 
-        eventstate = SDL_PollEvent (&event);
+        eventstate = s_fetchevent (&event);
 
         if (eventstate >= 1) {
             switch (event.type) {
