@@ -1,4 +1,4 @@
-/* $Id: menuimages.c,v 1.2 2004/05/20 16:55:30 stpohle Exp $
+/* $Id: menuimages.c,v 1.3 2004/09/26 02:28:06 stpohle Exp $
  * Menuhandling: labels */
 
 #include "basic.h"
@@ -48,7 +48,15 @@ _menuitem *menu_create_image (_menu *menu, char *name, int x, int y, int layer,
 	menuitems->pos.w = layer;
 	menuitems->type = MENU_image;
 	menuitems->ptrdata = (char *) img;
-	menuitems->rect = *rect;
+	
+	if (rect == NULL) {
+		menuitems->rect.x = 0;
+		menuitems->rect.y = 0;
+		menuitems->rect.w = img->w;
+		menuitems->rect.h = img->h;
+	} else
+		menuitems->rect = *rect;
+
 	strncpy (menuitems->label, name, MENU_TITLELEN);
 
 	return menuitems;
