@@ -1,4 +1,4 @@
-/* $Id: network.c,v 1.77 2006/08/13 21:26:50 stpohle Exp $ */
+/* $Id: network.c,v 1.79 2007/01/12 22:42:31 stpohle Exp $ */
 /*
 	network routines.
 */
@@ -132,7 +132,7 @@ network_init ()
             bman.notifygamemaster = 0;
     }
 
-    // we have got our socket.. so now allocate the memory for the resend_cache
+    // we have got our socket..
 	rscache_init ();
 	
     return 0;
@@ -874,9 +874,7 @@ net_game_send_dropitems (int pl_nr, _flyingitem ** fiptr, int cnt)
    this routine will set up some things for the network game
    after this the data should be transfered to the other clients.
 */
-void
-net_new_game ()
-{
+void net_new_game () {
     int p;
 
     /* set all multiplayer depending datas */
@@ -899,12 +897,10 @@ net_new_game ()
 /* send special use elements into the network, 
    to make sure nothing bad happens with explosions
    we send the ex_nr number too */
-void
-net_game_send_special (int pl_nr, int ex_nr, int type)
-{
+void net_game_send_special (int pl_nr, int ex_nr, int type) {
     int pl;
 
-    d_printf ("Send Special Data %d\n", pl_nr);
+    d_printf ("Send Special Data pl_nr:%d ex_nr:%d type:%d\n", pl_nr, ex_nr, type);
 
     if (pl_nr < 0 || pl_nr >= MAX_PLAYERS)
         return;
