@@ -21,14 +21,12 @@ struct _inpkg_index inpkg_index[PKG_IN_INDEX_NUM];
 int inpkg_index_pos = 0;
 
 
-/***
- *** help function to get the playernumber from the address.
- *** this function  does not indicate which player it is, this function only checks
- *** if the packet comed from a known player
- ***/
-int
-get_player_nr (char *host, char *port)
-{
+/*
+ * help function to get the playernumber from the address.
+ * this function  does not indicate which player it is, this function only checks
+ * if the packet comed from a known player
+ */
+int get_player_nr (char *host, char *port) {
     int i,
       res;
 
@@ -42,12 +40,10 @@ get_player_nr (char *host, char *port)
 }
 
 
-/***
- *** Packettype: error
- ***/
-void
-send_error (_net_addr * addr, char *text)
-{
+/*
+ * Packettype: error
+ */
+void send_error (_net_addr * addr, char *text) {
     struct pkg_error p_err;
 
     d_printf ("Send Network Error : %s\n", text);
@@ -61,9 +57,7 @@ send_error (_net_addr * addr, char *text)
 };
 
 
-void
-do_error (struct pkg_error *data, _net_addr * addr)
-{
+void do_error (struct pkg_error *data, _net_addr * addr) {
     d_printf ("Network Error from %s:%s : '%s'\n", addr->host, addr->port, data->text);
 
 	/* check if the packet comes from the server, the server
@@ -78,19 +72,17 @@ do_error (struct pkg_error *data, _net_addr * addr)
 
 
 
-/***
- *** Packettype: joingame
- *** client sends this to the server if he want's to join
- ***
- *** 1) check if this package comes from a already joined and known player
- ***    if so: just send the current playerlist back.
- *** else:
- *** 2) find free playerslot and add the player there
- *** 3) send to all players the new playerid
- ***/
-void
-do_joingame (struct pkg_joingame *p_jg, _net_addr * addr)
-{
+/*
+ * Packettype: joingame
+ * client sends this to the server if he want's to join
+ *
+ * 1) check if this package comes from a already joined and known player
+ *    if so: just send the current playerlist back.
+ * else:
+ * 2) find free playerslot and add the player there
+ * 3) send to all players the new playerid
+ */
+void do_joingame (struct pkg_joingame *p_jg, _net_addr * addr) {
     _player *pl;
     int i,
       vma,
@@ -208,9 +200,7 @@ do_joingame (struct pkg_joingame *p_jg, _net_addr * addr)
 };
 
 
-void
-send_joingame (_net_addr * addr, char *name, int secondplayer)
-{
+void send_joingame (_net_addr * addr, char *name, int secondplayer) {
     struct pkg_joingame p_jg;
     int vmi,
       vma,
@@ -344,7 +334,7 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
         pl->net.pingreq = pl->net.pingack + 5;
         if (GT_MP_PTPS)
             pl->net.flags = p_id->netflags;
-        if (p_id->host[0] != 0) {
+        if (p_id->host[0] != 0 && p_id->pl_nr != bman.p_servnr) { // copy addr only if p_id != server
             pl->net.addr.pl_nr = addr->pl_nr;
             strncpy (pl->net.addr.host, p_id->host, LEN_SERVERNAME);
             strncpy (pl->net.addr.port, p_id->port, LEN_PORT);
@@ -353,7 +343,7 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
         }
         /* player is used, we need to check if it's the second player from the server
          * to set it's host and port name */
-        else if (PS_IS_used (p_id->state)) {
+        else if (PS_IS_used (p_id->state) && p_id->pl_nr != bman.p_servnr) { // copy addr only if p_id != server
             strncpy (pl->net.addr.host, players[bman.p_servnr].net.addr.host, LEN_SERVERNAME);
             strncpy (pl->net.addr.port, players[bman.p_servnr].net.addr.port, LEN_PORT);
             memcpy (&pl->net.addr.sAddr, &players[bman.p_servnr].net.addr.sAddr,
@@ -361,7 +351,7 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
         }
 
         /* Check if we have to make a network test.. only client to client 
-         * we won't check 2 players too because i't won't be possible to send
+         * we won't check 2 players too because it won't be possible to send
          * something to them. 
          *
          * Check only as long as pl->state is still not a network player */
@@ -386,8 +376,12 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
         else
             pl->state &= (0xff - PSF_net);
 
-        if (pl->gfx_nr != p_id->gfx_nr)
-            player_set_gfx (pl, p_id->gfx_nr);
+		/* make sure we won't end up in an infinite loop, because of a slow network.
+		 * only accept the gfx data from other players. Our own we will not overwrite.*/
+		if ((bman.state != GS_wait
+			|| (p_id->pl_nr != bman.p_nr && p_id->pl_nr != bman.p2_nr))
+			&& pl->gfx_nr != p_id->gfx_nr)
+	            player_set_gfx (pl, p_id->gfx_nr);
         strncpy (pl->name, p_id->name, LEN_PLAYERNAME);
 
         if (GT_MP_PTPS) {
@@ -553,8 +547,8 @@ do_servermode (struct pkg_servermode *s_mod, _net_addr * addr)
     /* if we just have connected the bman.p_nr is still -1, so we handle the
        servermode packet still alittle diffrent */
     if ((!s_mod->lplayer2 && bman.p_nr == -1) || (s_mod->lplayer2 && bman.p2_nr == -1)) {
-        d_printf ("     Server gave us: p_nr: %d(old:%d), p_servnr: %d(old:%d)\n", s_mod->p_nr,
-                  bman.p_nr, s_mod->p_servnr, bman.p_servnr);
+        d_printf ("     Server gave us: p_nr/p2_nr: %d(old:%d), p_servnr: %d(old:%d), lplayer2:%d\n", s_mod->p_nr,
+                  bman.p_nr, s_mod->p_servnr, bman.p_servnr, s_mod->lplayer2);
 
         /* set the p_servnr to the playerslot which is the server */
         if (bman.p_servnr != s_mod->p_servnr) {
@@ -584,6 +578,8 @@ do_servermode (struct pkg_servermode *s_mod, _net_addr * addr)
             players[bman.p2_nr].net.flags = NETF_firewall + NETF_local2;
             players[bman.p2_nr].state &= (0xFF - PSF_net);
             strncpy (players[s_mod->p_nr].name, bman.player2name, LEN_PLAYERNAME);
+            send_playerid (addr, NULL, NULL, NULL, -1, -1, -1, 0);
+            send_teamdata (addr, -1);
         }
     }
 
@@ -632,7 +628,7 @@ send_servermode (_net_addr * addr, int pl_nr)
         d_printf ("Send ServerMode : update");
         break;
     default:
-        d_printf ("Send ServerMode : mode %d", s_mod.state);
+        d_printf ("Send ServerMode : mode %d", bman.state);
     }
 
 	d_printf ("Addr: %p\n", addr);
@@ -713,7 +709,7 @@ do_field (struct pkg_field *f_dat, _net_addr * addr)
 
     if (f_dat->x < map.size.x && f_dat->y < map.size.y) {
         /* convert the fielddata */
-        map.field[f_dat->x][f_dat->y].type = f_dat->type;
+        map.field[f_dat->x][f_dat->y].type = f_dat->type; // CHECK_BFIELD::: FOR BOMBS:::::
         map.field[f_dat->x][f_dat->y].mixframe = f_dat->mixframe;
         map.field[f_dat->x][f_dat->y].special = f_dat->special;
         for (i = 0; i < 4; i++) { /* set the explosion field data */
@@ -996,9 +992,7 @@ do_playermove (struct pkg_playermove *p_dat, _net_addr * addr)
 /***
  *** Packettype: bombdata
  ***/
-void
-do_bombdata (struct pkg_bombdata *b_dat, _net_addr * addr)
-{
+void do_bombdata (struct pkg_bombdata *b_dat, _net_addr * addr) {
     _bomb *bomb;
 
     if (addr->pl_nr == -1)
@@ -1051,10 +1045,15 @@ do_bombdata (struct pkg_bombdata *b_dat, _net_addr * addr)
     bomb->r = b_dat->r;
     bomb->ex_nr = NTOH32 (b_dat->ex_nr);
     bomb->state = b_dat->state & 0x0F;
+	
+	if (bomb->mode != b_dat->state >> 4) {		// bombmode changed set source to current position
+		bomb->source.x = bomb->pos.x;
+		bomb->source.y = bomb->pos.y;
+	}
     bomb->mode = b_dat->state >> 4;
-    bomb->speed = I16TOF (NTOH16 (b_dat->speed));
-    bomb->dest.x = NTOH16 (b_dat->destx);
-    bomb->dest.y = NTOH16 (b_dat->desty);
+    bomb->fdata = I16TOF (NTOH16 (b_dat->fdata));
+    bomb->dest.x = I16TOF (NTOH16 (b_dat->destx));
+    bomb->dest.y = I16TOF (NTOH16 (b_dat->desty));
 
     if (bomb->state == BS_exploding)
         bomb_explode (bomb, 0);
@@ -1079,9 +1078,9 @@ send_bombdata (_net_addr * addr, int p, int b, _bomb * bomb)
     b_dat.b_nr = b;
     b_dat.p_nr = p;
     b_dat.h.flags = PKGF_ackreq;
-    b_dat.speed = HTON16 (FTOI16 (bomb->speed));
-    b_dat.destx = HTON16 (bomb->dest.x);
-    b_dat.desty = HTON16 (bomb->dest.y);
+    b_dat.fdata = HTON16 (FTOI16 (bomb->fdata));
+    b_dat.destx = HTON16 (FTOI16 (bomb->dest.x));
+    b_dat.desty = HTON16 (FTOI16 (bomb->dest.y));
 
     send_pkg ((struct pkg *) &b_dat, addr);
 };
@@ -1529,9 +1528,7 @@ do_dropitems (struct pkg_dropitem *di_pkg, _net_addr * addr)
  *** Packettype: special
  *** moves/bombs... whatever will be send as we use it 
  ***/
-void
-do_special (struct pkg_special *sp_pkg, _net_addr * addr)
-{
+void do_special (struct pkg_special *sp_pkg, _net_addr * addr) {
     d_printf ("do_special (addr %d, pl_nr %d, typ %d)\n", addr->pl_nr, sp_pkg->pl_nr, sp_pkg->typ);
     if (addr->pl_nr == -1 || sp_pkg->pl_nr == -1 || sp_pkg->pl_nr == bman.p_nr
         || sp_pkg->pl_nr == bman.p2_nr)
@@ -1544,9 +1541,9 @@ do_special (struct pkg_special *sp_pkg, _net_addr * addr)
         special_use (sp_pkg->pl_nr);
     }
 
-    /* cleas special */
+    /* clear special */
     else if (sp_pkg->typ == SP_clear)
-        special_clear (sp_pkg->pl_nr);
+        players[sp_pkg->pl_nr].special.clear = 1;
 };
 
 
@@ -1676,10 +1673,6 @@ do_respawn (struct pkg_respawn *r_pkg, _net_addr * addr)
     if (addr->pl_nr == -1 || r_pkg->pl_nr == -1)
         return;
 
-    /* check if the right player is sending the information */
-    if (addr->pl_nr != bman.p_servnr && r_pkg->pl_nr != addr->pl_nr)
-        return;
-
     if ((r_pkg->state & PSF_respawn) == PSF_respawn) {
         players[r_pkg->pl_nr].pos.x = r_pkg->x;
         players[r_pkg->pl_nr].pos.y = r_pkg->y;
