@@ -1,4 +1,4 @@
-/* $Id: player.c,v 1.103 2006/08/15 15:58:39 stpohle Exp $
+/* $Id: player.c,v 1.106 2007/12/09 22:37:38 stpohle Exp $
  * player.c - everything what have to do with the player */
 
 #include <SDL.h>
@@ -546,9 +546,9 @@ get_player_on (float x, float y, int pl_nr[])
 void
 player_died (_player * player, signed char dead_by, int network)
 {
-	if (PS_IS_netplayer (player->state) && network == 0)
+	if ((player - players) != bman.p_nr && (player - players) != bman.p2_nr	&& PS_IS_netplayer (player->state) && network == 0) 
 		return;
-		
+	
     // player die !
     d_printf ("player_died (pl_nr:%d : %10s) current state: %d\n", player - players, player->name, player->state);
 
@@ -859,7 +859,7 @@ int
 player_findfreebomb (_player * player)
 {
     int i,
-      bombused = 0,
+	  bombused = 0,
       res = -1,
       nr;
 
@@ -868,22 +868,19 @@ player_findfreebomb (_player * player)
     if (player->bomb_lastex < 0 || player->bomb_lastex >= MAX_BOMBS)
         player->bomb_lastex = 0;
 
-    for (i = 0; i < MAX_BOMBS; i++) {
-        nr = player->bomb_lastex + 1 + i;
-        if (nr < 0 || nr >= MAX_BOMBS) // i out of range .. restart at bomb 0
-            nr -= MAX_BOMBS;
-
-        if (player->bombs[i].state == BS_off) { /* check if this bomb is free */
+    for (i = 0, nr = player->bomb_lastex, bombused = 0; i < MAX_BOMBS; i++) {
+		nr++;
+        if (nr >= MAX_BOMBS) // start at 0
+            nr = 0;
+		
+        if (player->bombs[nr].state == BS_off) { /* check if this bomb is free */
             if (res == -1)
-                res = i;
+                res = nr;
         }
         else
             bombused++;         // count number of used bombs
     }
 
-    if (res == -1 && i == player->bomb_lastex && player->bombs[i].state == BS_off)
-        res = i;
-
     if (bombused >= player->bombs_n)
         res = -1;               /* all max number of bombs lay */
 
@@ -901,7 +898,7 @@ void player_checkdeath (int pnr) {
     if (map.state == MS_normal && bman.gametype == GT_deathmatch 
 		&& PS_IS_dead (player->state) && player->frame >= gfx.dead.frames) {
 		/* check new position */
-		d_printf ("Respawn for player %s\n", player->name);
+		d_printf ("player_checkdeath: Respawn for player %s\n", player->name);
 
 		player->pos.x = -1;
 		player->pos.y = -1;
