@@ -1,4 +1,4 @@
-/* $Id: sound.c,v 1.7 2005/04/09 18:22:41 stpohle Exp $ */
+/* $Id: sound.c,v 1.8 2005/07/06 13:11:56 stpohle Exp $ */
 /* sound */
 
 #include "sound.h"
@@ -80,11 +80,6 @@ void
 snd_init ()
 {
 #if HAVE_SDL_MIXER
-	if (bman.dedicated) {
-		snd.inited = 0;
-		return;
-	}
-	
     if (Mix_OpenAudio (snd.audio_rate, snd.audio_format, snd.audio_channels, 1024) < 0) {
         d_printf ("Couldn't open audio mixer: %s\n", SDL_GetError ());
         snd.inited = 0;
