@@ -1,4 +1,4 @@
-/* $Id: sysfunc.c,v 1.24 2005/04/08 00:18:29 stpohle Exp $
+/* $Id: sysfunc.c,v 1.26 2007/12/09 22:13:03 stpohle Exp $
     sysfunc.c - this file hold some routines for the system functions..
     like d_delay
 */
@@ -27,6 +27,16 @@ s_delay (int ms)
 };
 
 
+int
+s_fetchevent (SDL_Event *event)
+{
+	if (SDL_PollEvent (event))
+		return 1;
+  	s_delay (20);
+	return 0;
+}
+
+
 int
 s_random (int maxnr)
 {
@@ -42,6 +52,18 @@ s_random (int maxnr)
 #endif
 };
 
+
+#if !defined(HAVE_RINTF) && !defined(HAVE_RINT)
+inline float rintf (float f) {
+       if (CUTINT (f) < 0.5f)
+               return (floorf (f));
+       else
+               return (floorf (f + 1.0f));
+};
+#endif
+
+
+
 static char homedir[255];
 
 char *
@@ -223,15 +245,6 @@ inline Sint32 s_swap32 (Sint32 i) {
 	return r;
 };
 
-#if !defined(HAVE_RINTF) && !defined(HAVE_RINT)
-inline float rintf (float f) {
-	if (CUTINT (f) < 0.5f)
-		return (floorf (f));
-	else
-		return (floorf (f + 1.0f));
-};
-#endif
-
 
 extern Uint32 game_timediff, game_timediff1;
 
@@ -319,3 +332,6 @@ float absol(float f) {
 	if (f<0) f*=-1;
 return f;
 }
+
+
+
